@@ -48,6 +48,10 @@ class HiveType(Enum):
     SOFTWARE = "software"
     SYSTEM = "system"
     USRCLASS = "usrclass.dat"
+    BCD = "bcd"
+    COMPONENTS = "components"
+    DEFAULT = "default"
+    SCHEMA = "schema.dat"
 
 
 class RegistryKeyHasNoParentException(RegistryParse.RegistryStructureDoesNotExist):
@@ -152,8 +156,11 @@ class RegistryValue(object):
         """
         return self._vkrecord.data_type_str()
 
-    def value(self):
-        return self._vkrecord.data()
+    def value(self, overrun=0):
+        return self._vkrecord.data(overrun)
+
+    def raw_data(self, overrun=0):
+        return self._vkrecord.raw_data(overrun)
 
 
 class RegistryKey(object):
@@ -261,9 +268,12 @@ class RegistryKey(object):
         """
         if name == "(default)":
             name = ""
-        for v in self._nkrecord.values_list().values():
-            if v.name().lower() == name.lower():
-                return RegistryValue(v)
+        try:
+            for v in self._nkrecord.values_list().values():
+                if v.name().lower() == name.lower():
+                    return RegistryValue(v)
+        except RegistryParse.RegistryStructureDoesNotExist:
+            raise RegistryValueNotFoundException(self.path() + " : " + name)
         raise RegistryValueNotFoundException(self.path() + " : " + name)
 
     def find_key(self, path):
@@ -330,6 +340,14 @@ class Registry(object):
             return HiveType.SYSTEM
         elif temp.lower() == HiveType.USRCLASS.value:
             return HiveType.USRCLASS
+        elif temp.lower() == HiveType.BCD.value:
+            return HiveType.BCD
+        elif temp.lower() == HiveType.COMPONENTS.value:
+            return HiveType.COMPONENTS
+        elif temp.lower() == HiveType.DEFAULT.value:
+            return HiveType.DEFAULT
+        elif temp.lower() == HiveType.SCHEMA.value:
+            return HiveType.SCHEMA
         else:
             return HiveType.UNKNOWN
 
